summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorThierry Escande <thierry.escande@linux.intel.com>2013-09-09 18:27:06 +0200
committerSamuel Ortiz <sameo@linux.intel.com>2013-09-10 15:57:26 +0200
commit93fcbbea33388d20b019c5e857266ef31a589a66 (patch)
tree8b96477d20d52902db01bf766ac8aa9788b2325a
parentb42a9e6b128c4928c37b91d38a6ca7d5fd52e10c (diff)
downloadneard-93fcbbea33388d20b019c5e857266ef31a589a66.tar.gz
neard-93fcbbea33388d20b019c5e857266ef31a589a66.tar.bz2
neard-93fcbbea33388d20b019c5e857266ef31a589a66.zip
nfc_copy: Update nfc_copy.h with SE command and firmware download status
It also renames NFC_CMD_FW_UPLOAD to NFC_CMD_FW_DOWNLOAD.
-rw-r--r--include/nfc_copy.h10
1 files changed, 7 insertions, 3 deletions
diff --git a/include/nfc_copy.h b/include/nfc_copy.h
index bb1aa47..29bed72 100644
--- a/include/nfc_copy.h
+++ b/include/nfc_copy.h
@@ -69,8 +69,8 @@
* starting a poll from a device which has a secure element enabled means
* we want to do SE based card emulation.
* @NFC_CMD_DISABLE_SE: Disable the physical link to a specific secure element.
* @NFC_CMD_FW_UPLOAD: Request to Load/flash firmware, or event to inform that
* some firmware was loaded
* @NFC_EVENT_SE_ADDED: Event emitted when a new secure element is discovered.
* This typically will be sent whenever a new NFC controller with either
* an embedded SE or an UICC one connected to it through SWP.
@@ -84,6 +84,7 @@
* @NFC_EVENT_SE_TRANSACTION: This event is sent when an application running on
* a specific SE notifies us about the end of a transaction. The parameter
* for this event is the application ID (AID).
+ * @NFC_CMD_GET_SE: Dump all discovered secure elements from an NFC controller.
*/
enum nfc_commands {
NFC_CMD_UNSPEC,
@@ -107,11 +108,12 @@ enum nfc_commands {
NFC_CMD_DISABLE_SE,
NFC_CMD_LLC_SDREQ,
NFC_EVENT_LLC_SDRES,
- NFC_CMD_FW_UPLOAD,
+ NFC_CMD_FW_DOWNLOAD,
NFC_EVENT_SE_ADDED,
NFC_EVENT_SE_REMOVED,
NFC_EVENT_SE_CONNECTIVITY,
NFC_EVENT_SE_TRANSACTION,
+ NFC_CMD_GET_SE,
/* private: internal use only */
__NFC_CMD_AFTER_LAST
};
@@ -144,6 +146,7 @@ enum nfc_commands {
* @NFC_ATTR_FIRMWARE_NAME: Free format firmware version
* @NFC_ATTR_SE_INDEX: Secure element index
* @NFC_ATTR_SE_TYPE: Secure element type (UICC or EMBEDDED)
+ * @NFC_ATTR_FIRMWARE_DOWNLOAD_STATUS: Firmware download operation status
*/
enum nfc_attrs {
NFC_ATTR_UNSPEC,
@@ -170,6 +173,7 @@ enum nfc_attrs {
NFC_ATTR_SE_INDEX,
NFC_ATTR_SE_TYPE,
NFC_ATTR_SE_AID,
+ NFC_ATTR_FIRMWARE_DOWNLOAD_STATUS,
/* private: internal use only */
__NFC_ATTR_AFTER_LAST
};
@@ -69,8 +69,8 @@
* we want to do SE based card emulation.
* @NFC_CMD_DISABLE_SE: Disable the physical link to a specific secure element.
- * @NFC_CMD_FW_UPLOAD: Request to Load/flash firmware, or event to inform that
- * some firmware was loaded
+ * @NFC_CMD_FW_DOWNLOAD: Request to Load/flash firmware, or event to inform
+ * that some firmware was loaded
* @NFC_EVENT_SE_ADDED: Event emitted when a new secure element is discovered.
* This typically will be sent whenever a new NFC controller with either